# Snek5000 solver for DNS of Taylor-Green Vortices (TGV)

This [Snek5000] solver demonstrates how to write a solver for a particular usecase taken
from the [NekExamples repo]. Something completely different than a high speed train...

## Install

```sh
pip install snek5000-tgv
```

For more details, see https://snek5000.readthedocs.io/en/latest/install.html

[nekexamples repo]: https://github.com/Nek5000/NekExamples/tree/master/tgv
[snek5000]: https://github.com/snek5000/snek5000
